@@ -146,13 +146,44 @@ def parse_list_objects(result, body):
         result.next_marker = _find_object(root, 'NextMarker', url_encoded)
 
     for contents_node in root.findall('Contents'):
+        owner = None
+        if contents_node.find("Owner") is not None:
+            owner = Owner(_find_tag(contents_node, 'Owner/DisplayName'), _find_tag(contents_node, 'Owner/ID'))
         result.object_list.append(SimplifiedObjectInfo(
             _find_object(contents_node, 'Key', url_encoded),
             iso8601_to_unixtime(_find_tag(contents_node, 'LastModified')),
             _find_tag(contents_node, 'ETag').strip('"'),
             _find_tag(contents_node, 'Type'),
             int(_find_tag(contents_node, 'Size')),
-            _find_tag(contents_node, 'StorageClass')
+            _find_tag(contents_node, 'StorageClass'),
+            owner
+        ))
+
+    for prefix_node in root.findall('CommonPrefixes'):
+        result.prefix_list.append(_find_object(prefix_node, 'Prefix', url_encoded))
+
+    return result
+
+
+def parse_list_objects_v2(result, body):
+    root = ElementTree.fromstring(body)
+    url_encoded = _is_url_encoding(root)
+    result.is_truncated = _find_bool(root, 'IsTruncated')
+    if result.is_truncated:
+        result.next_continuation_token = _find_object(root, 'NextContinuationToken', url_encoded)
+
+    for contents_node in root.findall('Contents'):
+        owner = None
+        if contents_node.find("Owner") is not None:
+            owner = Owner(_find_tag(contents_node, 'Owner/DisplayName'), _find_tag(contents_node, 'Owner/ID'))
+        result.object_list.append(SimplifiedObjectInfo(
+            _find_object(contents_node, 'Key', url_encoded),
+            iso8601_to_unixtime(_find_tag(contents_node, 'LastModified')),
+            _find_tag(contents_node, 'ETag').strip('"'),
+            _find_tag(contents_node, 'Type'),
+            int(_find_tag(contents_node, 'Size')),
+            _find_tag(contents_node, 'StorageClass'),
+            owner
         ))
 
     for prefix_node in root.findall('CommonPrefixes'):
@@ -341,6 +372,12 @@ def _parse_bucket_encryption_info(node):
     else:
         rule.kms_master_keyid = to_string(kmsnode.text)
 
+    kms_data_encryption_node = node.find("KMSDataEncryption")
+    if kms_data_encryption_node is None or kms_data_encryption_node.text is None:
+        rule.kms_data_encryption = None
+    else:
+        rule.kms_data_encryption = to_string(kms_data_encryption_node.text)
+
     return rule
 
 def parse_get_bucket_referer(result, body):
@@ -1150,6 +1187,9 @@ def to_put_bucket_encryption(rule):
     if rule.kms_master_keyid:
         _add_text_child(apply_node, "KMSMasterKeyID", rule.kms_master_keyid)
 
+    if rule.kms_data_encryption:
+        _add_text_child(apply_node, "KMSDataEncryption", rule.kms_data_encryption)
+
     return _node_to_string(root)
 
 def parse_get_bucket_encryption(result, body):
@@ -1164,6 +1204,12 @@ def parse_get_bucket_encryption(result, body):
     else:
         result.kms_master_keyid = to_string(kmsnode.text)
 
+    kms_data_encryption_node = apply_node.find('KMSDataEncryption')
+    if kms_data_encryption_node is None or kms_data_encryption_node.text is None:
+        result.kms_data_encryption = None
+    else:
+        result.kms_data_encryption = to_string(kms_data_encryption_node.text)
+
     return result
 
 def parse_list_object_versions(result, body):
